"""Common filenames and locations for topographic data, meshes and outputs.
Also includes origin for slump scenario.
"""

from os import sep, environ
from os.path import expanduser
from utilities.polygon import read_polygon
import sys
from pmesh.create_mesh import convert_points_from_latlon_to_utm
from coordinate_transforms.redfearn import degminsec2decimal_degrees
from time import localtime, strftime
from os import getcwd

#Making assumptions about the location of scenario data
scenario_dir_name = 'pt_hedland_tsunami_scenario_2006'

# onshore data from 30m DTED level 2
onshore_name = 'pt_hedland_onshore_30m_dted' # get from Neil/Ingo (DEM or topo data)
# offshore data from GA digitised charts
offshore_name1 = 'pt_hedland_offshore_points'
# offshore data from AHO fairsheets
offshore_name2 = 'pt_hedland_offshore_points_fairsheet'
# coastline developed from 30m DTED
coast_name = 'pt_hedland_coastline_points'

boundary_basename = 'SU-AU_clip'

#swollen/ all data output
basename = 'source'

codename = 'project.py'

if sys.platform == 'win32':
    home = environ['INUNDATIONHOME']     #Sandpit's parent dir
else:    
    home = expanduser('~')

#Derive subdirectories and filenames
time = strftime('%Y%m%d_%H%M%S',localtime()) #gets time for new dir
outputtimedir = home+sep+scenario_dir_name+sep+'output'+sep+time+sep
meshdir = home+sep+scenario_dir_name+sep+'meshes'+sep
datadir = home+sep+scenario_dir_name+sep+'topographies'+sep
gaugedir = home+sep+scenario_dir_name+sep+'gauges'+sep
polygondir = home+sep+scenario_dir_name+sep+'polygons'+sep
boundarydir = home+sep+scenario_dir_name+sep+'boundaries'+sep
#output dir without time
outputdir = home+sep+scenario_dir_name+sep+'output'+sep
tidedir = home+sep+scenario_dir_name+sep+'tide_data'+sep

print'bound', boundarydir

#gauge_filename = gaugedir + 'onslow_gauges.xya'
#for MOST
gauge_filename = gaugedir + 'pt_hedland_gauges.xya'

tidal_filename = tidedir + 'pt_hedland_tide.txt'

# boundary source data
#MOST_dir = 'f:'+sep+'3'+sep+'ehn'+sep+'users'+sep+'davidb'+sep+'tsunami'+sep+'WA_project'+sep+'SU-AU_90'+sep+'most_2'+sep+'detailed'+sep

codedir = getcwd()+sep
                                
codedirname = codedir + 'project.py'

meshname = meshdir + basename

onshore_dem_name = datadir + onshore_name

offshore_dem_name1 = datadir + offshore_name1
offshore_dem_name2 = datadir + offshore_name2

combined_dem_name = datadir + 'pt_hedland_combined_elevation'

outputname = outputtimedir + basename  #Used by post processing

# clipping region to make DEM (pts file) from onshore data
eastingmin = 594000
eastingmax = 715000
northingmin = 7720000
northingmax = 7880000

# for ferret2sww
#south = 
#north = 
#west = 
#east = 

# region to export (used from export_results.py)

#e_min_area = 300000
#e_max_area = 310000
#n_min_area = 7600000
#n_max_area = 7610000

refzone = 50 # confirm with Hamish

# bounding polygon provided by Hamish
d0 = [818732.55, 8062768.27]
d1 = [708940.32, 7750510.33]
d2 = [656561.15, 7732615.11]
d3 = [604415.81, 7733013.56]
d4 = [517682.34, 7899310.22]

polyAll = [d0, d1, d2, d3, d4]

#Interior region - Pt Hedland town
i0 = [690000, 7750510.33] # these are just currently close to d1, d2 and d3
i1 = [656561.15, 7750000]
i2 = [620000, 7733013.56]

poly_pt_hedland = [i0, i1, i2]

#Are there other significant features?
j0 = []
j1 = []
j2 = []
j3 = []

poly_ = [j0, j1, j2, j3]

